1.0.0 API documentation: GLM_EXT_vector_double1_precision

| 1.0.0 API documentation

Typedefs
GLM_EXT_vector_double1_precision
Stable extensions

## Typedefs
typedef vec< 1, double, highp > | highp_dvec1
| 1 component vector of double-precision floating-point numbers using high precision arithmetic in term of ULPs.
typedef vec< 1, double, lowp > | lowp_dvec1
| 1 component vector of double-precision floating-point numbers using low precision arithmetic in term of ULPs.
typedef vec< 1, double, mediump > | mediump_dvec1
| 1 component vector of double-precision floating-point numbers using medium precision arithmetic in term of ULPs.

## Detailed Description

Exposes highp_dvec1, mediump_dvec1 and lowp_dvec1 types.

Include <glm/ext/vector_double1_precision.hpp> to use the features of this extension.

See also
  GLM_EXT_vector_double1